Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mumble-voip/speexdsp.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorslicer <slicer@mumble.hive.no>2009-12-22 22:02:03 +0300
committerslicer <slicer@mumble.hive.no>2009-12-22 22:02:03 +0300
commit5e4e3a2285b3ea8264129d2658335c4bc27d1645 (patch)
treeab3984fcd8d07f77201b160c2170988b863c98e6 /include
parenta6d05eb5ff9d5062852cdf7df574bec728921ef9 (diff)
Split libspeex and libspeexdsp
Diffstat (limited to 'include')
-rw-r--r--include/speex/Makefile.am8
-rw-r--r--include/speex/speex.h430
-rw-r--r--include/speex/speex_bits.h174
-rw-r--r--include/speex/speex_buffer.h4
-rw-r--r--include/speex/speex_callbacks.h138
-rw-r--r--include/speex/speex_echo.h4
-rw-r--r--include/speex/speex_header.h98
-rw-r--r--include/speex/speex_jitter.h4
-rw-r--r--include/speex/speex_preprocess.h4
-rw-r--r--include/speex/speex_resampler.h4
-rw-r--r--include/speex/speex_stereo.h4
-rw-r--r--include/speex/speexdsp_config_types.h.in (renamed from include/speex/speex_config_types.h.in)0
-rw-r--r--include/speex/speexdsp_types.h (renamed from include/speex/speex_types.h)8
13 files changed, 19 insertions, 861 deletions
diff --git a/include/speex/Makefile.am b/include/speex/Makefile.am
index 2ae34f9..c462a05 100644
--- a/include/speex/Makefile.am
+++ b/include/speex/Makefile.am
@@ -1,9 +1,7 @@
# Disable automatic dependency tracking if using other tools than gcc and gmake
#AUTOMAKE_OPTIONS = no-dependencies
-nodist_pkginclude_HEADERS = speex_config_types.h
-
-pkginclude_HEADERS = speex.h speex_bits.h speex_buffer.h speex_callbacks.h \
- speex_echo.h speex_header.h speex_jitter.h speex_preprocess.h speex_resampler.h \
- speex_stereo.h speex_types.h
+nodist_pkginclude_HEADERS = speexdsp_config_types.h
+pkginclude_HEADERS = speex_echo.h speex_jitter.h speex_preprocess.h speex_resampler.h \
+ speexdsp_types.h
diff --git a/include/speex/speex.h b/include/speex/speex.h
deleted file mode 100644
index 157e7aa..0000000
--- a/include/speex/speex.h
+++ /dev/null
@@ -1,430 +0,0 @@
-/* Copyright (C) 2002-2006 Jean-Marc Valin*/
-/**
- @file speex.h
- @brief Describes the different modes of the codec
-*/
-/*
- Redistribution and use in source and binary forms, with or without
- modification, are permitted provided that the following conditions
- are met:
-
- - Redistributions of source code must retain the above copyright
- notice, this list of conditions and the following disclaimer.
-
- - Redistributions in binary form must reproduce the above copyright
- notice, this list of conditions and the following disclaimer in the
- documentation and/or other materials provided with the distribution.
-
- - Neither the name of the Xiph.org Foundation nor the names of its
- contributors may be used to endorse or promote products derived from
- this software without specific prior written permission.
-
- THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FOUNDATION OR
- CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
- PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
- LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-*/
-
-#ifndef SPEEX_H
-#define SPEEX_H
-/** @defgroup Codec Speex encoder and decoder
- * This is the Speex codec itself.
- * @{
- */
-
-#ifdef _BUILD_SPEEX
-# include "speex_types.h"
-# include "speex_bits.h"
-#else
-# include <speex/speex_types.h>
-# include <speex/speex_bits.h>
-#endif
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-/* Values allowed for *ctl() requests */
-
-/** Set enhancement on/off (decoder only) */
-#define SPEEX_SET_ENH 0
-/** Get enhancement state (decoder only) */
-#define SPEEX_GET_ENH 1
-
-/*Would be SPEEX_SET_FRAME_SIZE, but it's (currently) invalid*/
-/** Obtain frame size used by encoder/decoder */
-#define SPEEX_GET_FRAME_SIZE 3
-
-/** Set quality value */
-#define SPEEX_SET_QUALITY 4
-/** Get current quality setting */
-/* #define SPEEX_GET_QUALITY 5 -- Doesn't make much sense, does it? */
-
-/** Set sub-mode to use */
-#define SPEEX_SET_MODE 6
-/** Get current sub-mode in use */
-#define SPEEX_GET_MODE 7
-
-/** Set low-band sub-mode to use (wideband only)*/
-#define SPEEX_SET_LOW_MODE 8
-/** Get current low-band mode in use (wideband only)*/
-#define SPEEX_GET_LOW_MODE 9
-
-/** Set high-band sub-mode to use (wideband only)*/
-#define SPEEX_SET_HIGH_MODE 10
-/** Get current high-band mode in use (wideband only)*/
-#define SPEEX_GET_HIGH_MODE 11
-
-/** Set VBR on (1) or off (0) */
-#define SPEEX_SET_VBR 12
-/** Get VBR status (1 for on, 0 for off) */
-#define SPEEX_GET_VBR 13
-
-/** Set quality value for VBR encoding (0-10) */
-#define SPEEX_SET_VBR_QUALITY 14
-/** Get current quality value for VBR encoding (0-10) */
-#define SPEEX_GET_VBR_QUALITY 15
-
-/** Set complexity of the encoder (0-10) */
-#define SPEEX_SET_COMPLEXITY 16
-/** Get current complexity of the encoder (0-10) */
-#define SPEEX_GET_COMPLEXITY 17
-
-/** Set bit-rate used by the encoder (or lower) */
-#define SPEEX_SET_BITRATE 18
-/** Get current bit-rate used by the encoder or decoder */
-#define SPEEX_GET_BITRATE 19
-
-/** Define a handler function for in-band Speex request*/
-#define SPEEX_SET_HANDLER 20
-
-/** Define a handler function for in-band user-defined request*/
-#define SPEEX_SET_USER_HANDLER 22
-
-/** Set sampling rate used in bit-rate computation */
-#define SPEEX_SET_SAMPLING_RATE 24
-/** Get sampling rate used in bit-rate computation */
-#define SPEEX_GET_SAMPLING_RATE 25
-
-/** Reset the encoder/decoder memories to zero*/
-#define SPEEX_RESET_STATE 26
-
-/** Get VBR info (mostly used internally) */
-#define SPEEX_GET_RELATIVE_QUALITY 29
-
-/** Set VAD status (1 for on, 0 for off) */
-#define SPEEX_SET_VAD 30
-
-/** Get VAD status (1 for on, 0 for off) */
-#define SPEEX_GET_VAD 31
-
-/** Set Average Bit-Rate (ABR) to n bits per seconds */
-#define SPEEX_SET_ABR 32
-/** Get Average Bit-Rate (ABR) setting (in bps) */
-#define SPEEX_GET_ABR 33
-
-/** Set DTX status (1 for on, 0 for off) */
-#define SPEEX_SET_DTX 34
-/** Get DTX status (1 for on, 0 for off) */
-#define SPEEX_GET_DTX 35
-
-/** Set submode encoding in each frame (1 for yes, 0 for no, setting to no breaks the standard) */
-#define SPEEX_SET_SUBMODE_ENCODING 36
-/** Get submode encoding in each frame */
-#define SPEEX_GET_SUBMODE_ENCODING 37
-
-/*#define SPEEX_SET_LOOKAHEAD 38*/
-/** Returns the lookahead used by Speex separately for an encoder and a decoder.
- * Sum encoder and decoder lookahead values to get the total codec lookahead. */
-#define SPEEX_GET_LOOKAHEAD 39
-
-/** Sets tuning for packet-loss concealment (expected loss rate) */
-#define SPEEX_SET_PLC_TUNING 40
-/** Gets tuning for PLC */
-#define SPEEX_GET_PLC_TUNING 41
-
-/** Sets the max bit-rate allowed in VBR mode */
-#define SPEEX_SET_VBR_MAX_BITRATE 42
-/** Gets the max bit-rate allowed in VBR mode */
-#define SPEEX_GET_VBR_MAX_BITRATE 43
-
-/** Turn on/off input/output high-pass filtering */
-#define SPEEX_SET_HIGHPASS 44
-/** Get status of input/output high-pass filtering */
-#define SPEEX_GET_HIGHPASS 45
-
-/** Get "activity level" of the last decoded frame, i.e.
- how much damage we cause if we remove the frame */
-#define SPEEX_GET_ACTIVITY 47
-
-
-/* Preserving compatibility:*/
-/** Equivalent to SPEEX_SET_ENH */
-#define SPEEX_SET_PF 0
-/** Equivalent to SPEEX_GET_ENH */
-#define SPEEX_GET_PF 1
-
-
-
-
-/* Values allowed for mode queries */
-/** Query the frame size of a mode */
-#define SPEEX_MODE_FRAME_SIZE 0
-
-/** Query the size of an encoded frame for a particular sub-mode */
-#define SPEEX_SUBMODE_BITS_PER_FRAME 1
-
-
-
-/** Get major Speex version */
-#define SPEEX_LIB_GET_MAJOR_VERSION 1
-/** Get minor Speex version */
-#define SPEEX_LIB_GET_MINOR_VERSION 3
-/** Get micro Speex version */
-#define SPEEX_LIB_GET_MICRO_VERSION 5
-/** Get extra Speex version */
-#define SPEEX_LIB_GET_EXTRA_VERSION 7
-/** Get Speex version string */
-#define SPEEX_LIB_GET_VERSION_STRING 9
-
-/*#define SPEEX_LIB_SET_ALLOC_FUNC 10
-#define SPEEX_LIB_GET_ALLOC_FUNC 11
-#define SPEEX_LIB_SET_FREE_FUNC 12
-#define SPEEX_LIB_GET_FREE_FUNC 13
-
-#define SPEEX_LIB_SET_WARNING_FUNC 14
-#define SPEEX_LIB_GET_WARNING_FUNC 15
-#define SPEEX_LIB_SET_ERROR_FUNC 16
-#define SPEEX_LIB_GET_ERROR_FUNC 17
-*/
-
-/** Number of defined modes in Speex */
-#define SPEEX_NB_MODES 3
-
-/** modeID for the defined narrowband mode */
-#define SPEEX_MODEID_NB 0
-
-/** modeID for the defined wideband mode */
-#define SPEEX_MODEID_WB 1
-
-/** modeID for the defined ultra-wideband mode */
-#define SPEEX_MODEID_UWB 2
-
-struct SpeexMode;
-
-
-/* Prototypes for mode function pointers */
-
-/** Encoder state initialization function */
-typedef void *(*encoder_init_func)(const struct SpeexMode *mode);
-
-/** Encoder state destruction function */
-typedef void (*encoder_destroy_func)(void *st);
-
-/** Main encoding function */
-typedef int (*encode_func)(void *state, void *in, SpeexBits *bits);
-
-/** Function for controlling the encoder options */
-typedef int (*encoder_ctl_func)(void *state, int request, void *ptr);
-
-/** Decoder state initialization function */
-typedef void *(*decoder_init_func)(const struct SpeexMode *mode);
-
-/** Decoder state destruction function */
-typedef void (*decoder_destroy_func)(void *st);
-
-/** Main decoding function */
-typedef int (*decode_func)(void *state, SpeexBits *bits, void *out);
-
-/** Function for controlling the decoder options */
-typedef int (*decoder_ctl_func)(void *state, int request, void *ptr);
-
-
-/** Query function for a mode */
-typedef int (*mode_query_func)(const void *mode, int request, void *ptr);
-
-/** Struct defining a Speex mode */
-typedef struct SpeexMode {
- /** Pointer to the low-level mode data */
- const void *mode;
-
- /** Pointer to the mode query function */
- mode_query_func query;
-
- /** The name of the mode (you should not rely on this to identify the mode)*/
- const char *modeName;
-
- /**ID of the mode*/
- int modeID;
-
- /**Version number of the bitstream (incremented every time we break
- bitstream compatibility*/
- int bitstream_version;
-
- /** Pointer to encoder initialization function */
- encoder_init_func enc_init;
-
- /** Pointer to encoder destruction function */
- encoder_destroy_func enc_destroy;
-
- /** Pointer to frame encoding function */
- encode_func enc;
-
- /** Pointer to decoder initialization function */
- decoder_init_func dec_init;
-
- /** Pointer to decoder destruction function */
- decoder_destroy_func dec_destroy;
-
- /** Pointer to frame decoding function */
- decode_func dec;
-
- /** ioctl-like requests for encoder */
- encoder_ctl_func enc_ctl;
-
- /** ioctl-like requests for decoder */
- decoder_ctl_func dec_ctl;
-
-} SpeexMode;
-
-/**
- * Returns a handle to a newly created Speex encoder state structure. For now,
- * the "mode" argument can be &nb_mode or &wb_mode . In the future, more modes
- * may be added. Note that for now if you have more than one channels to
- * encode, you need one state per channel.
- *
- * @param mode The mode to use (either speex_nb_mode or speex_wb.mode)
- * @return A newly created encoder state or NULL if state allocation fails
- */
-void *speex_encoder_init(const SpeexMode *mode);
-
-/** Frees all resources associated to an existing Speex encoder state.
- * @param state Encoder state to be destroyed */
-void speex_encoder_destroy(void *state);
-
-/** Uses an existing encoder state to encode one frame of speech pointed to by
- "in". The encoded bit-stream is saved in "bits".
- @param state Encoder state
- @param in Frame that will be encoded with a +-2^15 range. This data MAY be
- overwritten by the encoder and should be considered uninitialised
- after the call.
- @param bits Bit-stream where the data will be written
- @return 0 if frame needs not be transmitted (DTX only), 1 otherwise
- */
-int speex_encode(void *state, float *in, SpeexBits *bits);
-
-/** Uses an existing encoder state to encode one frame of speech pointed to by
- "in". The encoded bit-stream is saved in "bits".
- @param state Encoder state
- @param in Frame that will be encoded with a +-2^15 range
- @param bits Bit-stream where the data will be written
- @return 0 if frame needs not be transmitted (DTX only), 1 otherwise
- */
-int speex_encode_int(void *state, spx_int16_t *in, SpeexBits *bits);
-
-/** Used like the ioctl function to control the encoder parameters
- *
- * @param state Encoder state
- * @param request ioctl-type request (one of the SPEEX_* macros)
- * @param ptr Data exchanged to-from function
- * @return 0 if no error, -1 if request in unknown, -2 for invalid parameter
- */
-int speex_encoder_ctl(void *state, int request, void *ptr);
-
-
-/** Returns a handle to a newly created decoder state structure. For now,
- * the mode argument can be &nb_mode or &wb_mode . In the future, more modes
- * may be added. Note that for now if you have more than one channels to
- * decode, you need one state per channel.
- *
- * @param mode Speex mode (one of speex_nb_mode or speex_wb_mode)
- * @return A newly created decoder state or NULL if state allocation fails
- */
-void *speex_decoder_init(const SpeexMode *mode);
-
-/** Frees all resources associated to an existing decoder state.
- *
- * @param state State to be destroyed
- */
-void speex_decoder_destroy(void *state);
-
-/** Uses an existing decoder state to decode one frame of speech from
- * bit-stream bits. The output speech is saved written to out.
- *
- * @param state Decoder state
- * @param bits Bit-stream from which to decode the frame (NULL if the packet was lost)
- * @param out Where to write the decoded frame
- * @return return status (0 for no error, -1 for end of stream, -2 corrupt stream)
- */
-int speex_decode(void *state, SpeexBits *bits, float *out);
-
-/** Uses an existing decoder state to decode one frame of speech from
- * bit-stream bits. The output speech is saved written to out.
- *
- * @param state Decoder state
- * @param bits Bit-stream from which to decode the frame (NULL if the packet was lost)
- * @param out Where to write the decoded frame
- * @return return status (0 for no error, -1 for end of stream, -2 corrupt stream)
- */
-int speex_decode_int(void *state, SpeexBits *bits, spx_int16_t *out);
-
-/** Used like the ioctl function to control the encoder parameters
- *
- * @param state Decoder state
- * @param request ioctl-type request (one of the SPEEX_* macros)
- * @param ptr Data exchanged to-from function
- * @return 0 if no error, -1 if request in unknown, -2 for invalid parameter
- */
-int speex_decoder_ctl(void *state, int request, void *ptr);
-
-
-/** Query function for mode information
- *
- * @param mode Speex mode
- * @param request ioctl-type request (one of the SPEEX_* macros)
- * @param ptr Data exchanged to-from function
- * @return 0 if no error, -1 if request in unknown, -2 for invalid parameter
- */
-int speex_mode_query(const SpeexMode *mode, int request, void *ptr);
-
-/** Functions for controlling the behavior of libspeex
- * @param request ioctl-type request (one of the SPEEX_LIB_* macros)
- * @param ptr Data exchanged to-from function
- * @return 0 if no error, -1 if request in unknown, -2 for invalid parameter
- */
-int speex_lib_ctl(int request, void *ptr);
-
-/** Default narrowband mode */
-extern const SpeexMode speex_nb_mode;
-
-/** Default wideband mode */
-extern const SpeexMode speex_wb_mode;
-
-/** Default "ultra-wideband" mode */
-extern const SpeexMode speex_uwb_mode;
-
-/** List of all modes available */
-extern const SpeexMode * const speex_mode_list[SPEEX_NB_MODES];
-
-/** Obtain one of the modes available */
-const SpeexMode * speex_lib_get_mode (int mode);
-
-#ifndef WIN32
-/* We actually override the function in the narrowband case so that we can avoid linking in the wideband stuff */
-#define speex_lib_get_mode(mode) ((mode)==SPEEX_MODEID_NB ? &speex_nb_mode : speex_lib_get_mode (mode))
-#endif
-
-#ifdef __cplusplus
-}
-#endif
-
-/** @}*/
-#endif
diff --git a/include/speex/speex_bits.h b/include/speex/speex_bits.h
deleted file mode 100644
index 234ec53..0000000
--- a/include/speex/speex_bits.h
+++ /dev/null
@@ -1,174 +0,0 @@
-/* Copyright (C) 2002 Jean-Marc Valin */
-/**
- @file speex_bits.h
- @brief Handles bit packing/unpacking
-*/
-/*
- Redistribution and use in source and binary forms, with or without
- modification, are permitted provided that the following conditions
- are met:
-
- - Redistributions of source code must retain the above copyright
- notice, this list of conditions and the following disclaimer.
-
- - Redistributions in binary form must reproduce the above copyright
- notice, this list of conditions and the following disclaimer in the
- documentation and/or other materials provided with the distribution.
-
- - Neither the name of the Xiph.org Foundation nor the names of its
- contributors may be used to endorse or promote products derived from
- this software without specific prior written permission.
-
- THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FOUNDATION OR
- CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
- PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
- LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-*/
-
-#ifndef BITS_H
-#define BITS_H
-/** @defgroup SpeexBits SpeexBits: Bit-stream manipulations
- * This is the structure that holds the bit-stream when encoding or decoding
- * with Speex. It allows some manipulations as well.
- * @{
- */
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-/** Bit-packing data structure representing (part of) a bit-stream. */
-typedef struct SpeexBits {
- char *chars; /**< "raw" data */
- int nbBits; /**< Total number of bits stored in the stream*/
- int charPtr; /**< Position of the byte "cursor" */
- int bitPtr; /**< Position of the bit "cursor" within the current char */
- int owner; /**< Does the struct "own" the "raw" buffer (member "chars") */
- int overflow;/**< Set to one if we try to read past the valid data */
- int buf_size;/**< Allocated size for buffer */
- int reserved1; /**< Reserved for future use */
- void *reserved2; /**< Reserved for future use */
-} SpeexBits;
-
-/** Initializes and allocates resources for a SpeexBits struct */
-void speex_bits_init(SpeexBits *bits);
-
-/** Initializes SpeexBits struct using a pre-allocated buffer*/
-void speex_bits_init_buffer(SpeexBits *bits, void *buff, int buf_size);
-
-/** Sets the bits in a SpeexBits struct to use data from an existing buffer (for decoding without copying data) */
-void speex_bits_set_bit_buffer(SpeexBits *bits, void *buff, int buf_size);
-
-/** Frees all resources associated to a SpeexBits struct. Right now this does nothing since no resources are allocated, but this could change in the future.*/
-void speex_bits_destroy(SpeexBits *bits);
-
-/** Resets bits to initial value (just after initialization, erasing content)*/
-void speex_bits_reset(SpeexBits *bits);
-
-/** Rewind the bit-stream to the beginning (ready for read) without erasing the content */
-void speex_bits_rewind(SpeexBits *bits);
-
-/** Initializes the bit-stream from the data in an area of memory */
-void speex_bits_read_from(SpeexBits *bits, const char *bytes, int len);
-
-/** Append bytes to the bit-stream
- *
- * @param bits Bit-stream to operate on
- * @param bytes pointer to the bytes what will be appended
- * @param len Number of bytes of append
- */
-void speex_bits_read_whole_bytes(SpeexBits *bits, const char *bytes, int len);
-
-/** Write the content of a bit-stream to an area of memory
- *
- * @param bits Bit-stream to operate on
- * @param bytes Memory location where to write the bits
- * @param max_len Maximum number of bytes to write (i.e. size of the "bytes" buffer)
- * @return Number of bytes written to the "bytes" buffer
-*/
-int speex_bits_write(SpeexBits *bits, char *bytes, int max_len);
-
-/** Like speex_bits_write, but writes only the complete bytes in the stream. Also removes the written bytes from the stream */
-int speex_bits_write_whole_bytes(SpeexBits *bits, char *bytes, int max_len);
-
-/** Append bits to the bit-stream
- * @param bits Bit-stream to operate on
- * @param data Value to append as integer
- * @param nbBits number of bits to consider in "data"
- */
-void speex_bits_pack(SpeexBits *bits, int data, int nbBits);
-
-/** Interpret the next bits in the bit-stream as a signed integer
- *
- * @param bits Bit-stream to operate on
- * @param nbBits Number of bits to interpret
- * @return A signed integer represented by the bits read
- */
-int speex_bits_unpack_signed(SpeexBits *bits, int nbBits);
-
-/** Interpret the next bits in the bit-stream as an unsigned integer
- *
- * @param bits Bit-stream to operate on
- * @param nbBits Number of bits to interpret
- * @return An unsigned integer represented by the bits read
- */
-unsigned int speex_bits_unpack_unsigned(SpeexBits *bits, int nbBits);
-
-/** Returns the number of bytes in the bit-stream, including the last one even if it is not "full"
- *
- * @param bits Bit-stream to operate on
- * @return Number of bytes in the stream
- */
-int speex_bits_nbytes(SpeexBits *bits);
-
-/** Same as speex_bits_unpack_unsigned, but without modifying the cursor position
- *
- * @param bits Bit-stream to operate on
- * @param nbBits Number of bits to look for
- * @return Value of the bits peeked, interpreted as unsigned
- */
-unsigned int speex_bits_peek_unsigned(SpeexBits *bits, int nbBits);
-
-/** Get the value of the next bit in the stream, without modifying the
- * "cursor" position
- *
- * @param bits Bit-stream to operate on
- * @return Value of the bit peeked (one bit only)
- */
-int speex_bits_peek(SpeexBits *bits);
-
-/** Advances the position of the "bit cursor" in the stream
- *
- * @param bits Bit-stream to operate on
- * @param n Number of bits to advance
- */
-void speex_bits_advance(SpeexBits *bits, int n);
-
-/** Returns the number of bits remaining to be read in a stream
- *
- * @param bits Bit-stream to operate on
- * @return Number of bits that can still be read from the stream
- */
-int speex_bits_remaining(SpeexBits *bits);
-
-/** Insert a terminator so that the data can be sent as a packet while auto-detecting
- * the number of frames in each packet
- *
- * @param bits Bit-stream to operate on
- */
-void speex_bits_insert_terminator(SpeexBits *bits);
-
-#ifdef __cplusplus
-}
-#endif
-
-/* @} */
-#endif
diff --git a/include/speex/speex_buffer.h b/include/speex/speex_buffer.h
index 59632b3..c10b1f9 100644
--- a/include/speex/speex_buffer.h
+++ b/include/speex/speex_buffer.h
@@ -35,9 +35,9 @@
#define SPEEX_BUFFER_H
#ifdef _BUILD_SPEEX
-# include "speex_types.h"
+# include "speexdsp_types.h"
#else
-# include <speex/speex_types.h>
+# include <speex/speexdsp_types.h>
#endif
#ifdef __cplusplus
diff --git a/include/speex/speex_callbacks.h b/include/speex/speex_callbacks.h
deleted file mode 100644
index 42bc9c3..0000000
--- a/include/speex/speex_callbacks.h
+++ /dev/null
@@ -1,138 +0,0 @@
-/* Copyright (C) 2002 Jean-Marc Valin*/
-/**
- @file speex_callbacks.h
- @brief Describes callback handling and in-band signalling
-*/
-/*
- Redistribution and use in source and binary forms, with or without
- modification, are permitted provided that the following conditions
- are met:
-
- - Redistributions of source code must retain the above copyright
- notice, this list of conditions and the following disclaimer.
-
- - Redistributions in binary form must reproduce the above copyright
- notice, this list of conditions and the following disclaimer in the
- documentation and/or other materials provided with the distribution.
-
- - Neither the name of the Xiph.org Foundation nor the names of its
- contributors may be used to endorse or promote products derived from
- this software without specific prior written permission.
-
- THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FOUNDATION OR
- CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
- PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
- LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-*/
-
-#ifndef SPEEX_CALLBACKS_H
-#define SPEEX_CALLBACKS_H
-/** @defgroup SpeexCallbacks Various definitions for Speex callbacks supported by the decoder.
- * @{
- */
-
-#ifdef _BUILD_SPEEX
-# include "speex.h"
-#else
-# include <speex/speex.h>
-#endif
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-/** Total number of callbacks */
-#define SPEEX_MAX_CALLBACKS 16
-
-/* Describes all the in-band requests */
-
-/*These are 1-bit requests*/
-/** Request for perceptual enhancement (1 for on, 0 for off) */
-#define SPEEX_INBAND_ENH_REQUEST 0
-/** Reserved */
-#define SPEEX_INBAND_RESERVED1 1
-
-/*These are 4-bit requests*/
-/** Request for a mode change */
-#define SPEEX_INBAND_MODE_REQUEST 2
-/** Request for a low mode change */
-#define SPEEX_INBAND_LOW_MODE_REQUEST 3
-/** Request for a high mode change */
-#define SPEEX_INBAND_HIGH_MODE_REQUEST 4
-/** Request for VBR (1 on, 0 off) */
-#define SPEEX_INBAND_VBR_QUALITY_REQUEST 5
-/** Request to be sent acknowledge */
-#define SPEEX_INBAND_ACKNOWLEDGE_REQUEST 6
-/** Request for VBR (1 for on, 0 for off) */
-#define SPEEX_INBAND_VBR_REQUEST 7
-
-/*These are 8-bit requests*/
-/** Send a character in-band */
-#define SPEEX_INBAND_CHAR 8
-/** Intensity stereo information */
-#define SPEEX_INBAND_STEREO 9
-
-/*These are 16-bit requests*/
-/** Transmit max bit-rate allowed */
-#define SPEEX_INBAND_MAX_BITRATE 10
-
-/*These are 32-bit requests*/
-/** Acknowledge packet reception */
-#define SPEEX_INBAND_ACKNOWLEDGE 12
-
-/** Callback function type */
-typedef int (*speex_callback_func)(SpeexBits *bits, void *state, void *data);
-
-/** Callback information */
-typedef struct SpeexCallback {
- int callback_id; /**< ID associated to the callback */
- speex_callback_func func; /**< Callback handler function */
- void *data; /**< Data that will be sent to the handler */
- void *reserved1; /**< Reserved for future use */
- int reserved2; /**< Reserved for future use */
-} SpeexCallback;
-
-/** Handle in-band request */
-int speex_inband_handler(SpeexBits *bits, SpeexCallback *callback_list, void *state);
-
-/** Standard handler for mode request (change mode, no questions asked) */
-int speex_std_mode_request_handler(SpeexBits *bits, void *state, void *data);
-
-/** Standard handler for high mode request (change high mode, no questions asked) */
-int speex_std_high_mode_request_handler(SpeexBits *bits, void *state, void *data);
-
-/** Standard handler for in-band characters (write to stderr) */
-int speex_std_char_handler(SpeexBits *bits, void *state, void *data);
-
-/** Default handler for user-defined requests: in this case, just ignore */
-int speex_default_user_handler(SpeexBits *bits, void *state, void *data);
-
-
-
-/** Standard handler for low mode request (change low mode, no questions asked) */
-int speex_std_low_mode_request_handler(SpeexBits *bits, void *state, void *data);
-
-/** Standard handler for VBR request (Set VBR, no questions asked) */
-int speex_std_vbr_request_handler(SpeexBits *bits, void *state, void *data);
-
-/** Standard handler for enhancer request (Turn enhancer on/off, no questions asked) */
-int speex_std_enh_request_handler(SpeexBits *bits, void *state, void *data);
-
-/** Standard handler for VBR quality request (Set VBR quality, no questions asked) */
-int speex_std_vbr_quality_request_handler(SpeexBits *bits, void *state, void *data);
-
-
-#ifdef __cplusplus
-}
-#endif
-
-/** @} */
-#endif
diff --git a/include/speex/speex_echo.h b/include/speex/speex_echo.h
index c01688b..d20cf48 100644
--- a/include/speex/speex_echo.h
+++ b/include/speex/speex_echo.h
@@ -38,9 +38,9 @@
* @{
*/
#ifdef _BUILD_SPEEX
-# include "speex_types.h"
+# include "speexdsp_types.h"
#else
-# include <speex/speex_types.h>
+# include <speex/speexdsp_types.h>
#endif
#ifdef __cplusplus
diff --git a/include/speex/speex_header.h b/include/speex/speex_header.h
deleted file mode 100644
index dfd1ce6..0000000
--- a/include/speex/speex_header.h
+++ /dev/null
@@ -1,98 +0,0 @@
-/* Copyright (C) 2002 Jean-Marc Valin */
-/**
- @file speex_header.h
- @brief Describes the Speex header
-*/
-/*
- Redistribution and use in source and binary forms, with or without
- modification, are permitted provided that the following conditions
- are met:
-
- - Redistributions of source code must retain the above copyright
- notice, this list of conditions and the following disclaimer.
-
- - Redistributions in binary form must reproduce the above copyright
- notice, this list of conditions and the following disclaimer in the
- documentation and/or other materials provided with the distribution.
-
- - Neither the name of the Xiph.org Foundation nor the names of its
- contributors may be used to endorse or promote products derived from
- this software without specific prior written permission.
-
- THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FOUNDATION OR
- CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
- PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
- LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-*/
-
-
-#ifndef SPEEX_HEADER_H
-#define SPEEX_HEADER_H
-/** @defgroup SpeexHeader SpeexHeader: Makes it easy to write/parse an Ogg/Speex header
- * This is the Speex header for the Ogg encapsulation. You don't need that if you just use RTP.
- * @{
- */
-
-#ifdef _BUILD_SPEEX
-# include "speex_types.h"
-#else
-# include <speex/speex_types.h>
-#endif
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-struct SpeexMode;
-
-/** Length of the Speex header identifier */
-#define SPEEX_HEADER_STRING_LENGTH 8
-
-/** Maximum number of characters for encoding the Speex version number in the header */
-#define SPEEX_HEADER_VERSION_LENGTH 20
-
-/** Speex header info for file-based formats */
-typedef struct SpeexHeader {
- char speex_string[SPEEX_HEADER_STRING_LENGTH]; /**< Identifies a Speex bit-stream, always set to "Speex " */
- char speex_version[SPEEX_HEADER_VERSION_LENGTH]; /**< Speex version */
- spx_int32_t speex_version_id; /**< Version for Speex (for checking compatibility) */
- spx_int32_t header_size; /**< Total size of the header ( sizeof(SpeexHeader) ) */
- spx_int32_t rate; /**< Sampling rate used */
- spx_int32_t mode; /**< Mode used (0 for narrowband, 1 for wideband) */
- spx_int32_t mode_bitstream_version; /**< Version ID of the bit-stream */
- spx_int32_t nb_channels; /**< Number of channels encoded */
- spx_int32_t bitrate; /**< Bit-rate used */
- spx_int32_t frame_size; /**< Size of frames */
- spx_int32_t vbr; /**< 1 for a VBR encoding, 0 otherwise */
- spx_int32_t frames_per_packet; /**< Number of frames stored per Ogg packet */
- spx_int32_t extra_headers; /**< Number of additional headers after the comments */
- spx_int32_t reserved1; /**< Reserved for future use, must be zero */
- spx_int32_t reserved2; /**< Reserved for future use, must be zero */
-} SpeexHeader;
-
-/** Initializes a SpeexHeader using basic information */
-void speex_init_header(SpeexHeader *header, int rate, int nb_channels, const struct SpeexMode *m);
-
-/** Creates the header packet from the header itself (mostly involves endianness conversion) */
-char *speex_header_to_packet(SpeexHeader *header, int *size);
-
-/** Creates a SpeexHeader from a packet */
-SpeexHeader *speex_packet_to_header(char *packet, int size);
-
-/** Frees the memory allocated by either speex_header_to_packet() or speex_packet_to_header() */
-void speex_header_free(void *ptr);
-
-#ifdef __cplusplus
-}
-#endif
-
-/** @} */
-#endif
diff --git a/include/speex/speex_jitter.h b/include/speex/speex_jitter.h
index 977916b..474b9f3 100644
--- a/include/speex/speex_jitter.h
+++ b/include/speex/speex_jitter.h
@@ -42,9 +42,9 @@
*/
#ifdef _BUILD_SPEEX
-# include "speex_types.h"
+# include "speexdsp_types.h"
#else
-# include <speex/speex_types.h>
+# include <speex/speexdsp_types.h>
#endif
#ifdef __cplusplus
diff --git a/include/speex/speex_preprocess.h b/include/speex/speex_preprocess.h
index 2730595..3a3e7ec 100644
--- a/include/speex/speex_preprocess.h
+++ b/include/speex/speex_preprocess.h
@@ -44,9 +44,9 @@
*/
#ifdef _BUILD_SPEEX
-# include "speex_types.h"
+# include "speexdsp_types.h"
#else
-# include <speex/speex_types.h>
+# include <speex/speexdsp_types.h>
#endif
#ifdef __cplusplus
diff --git a/include/speex/speex_resampler.h b/include/speex/speex_resampler.h
index 4d5913f..96dfe1e 100644
--- a/include/speex/speex_resampler.h
+++ b/include/speex/speex_resampler.h
@@ -85,9 +85,9 @@
#else /* OUTSIDE_SPEEX */
#ifdef _BUILD_SPEEX
-# include "speex_types.h"
+# include "speexdsp_types.h"
#else
-# include <speex/speex_types.h>
+# include <speex/speexdsp_types.h>
#endif
#endif /* OUTSIDE_SPEEX */
diff --git a/include/speex/speex_stereo.h b/include/speex/speex_stereo.h
index 6eb6c12..03f8b62 100644
--- a/include/speex/speex_stereo.h
+++ b/include/speex/speex_stereo.h
@@ -40,10 +40,10 @@
*/
#ifdef _BUILD_SPEEX
-# include "speex_types.h"
+# include "speexdsp_types.h"
# include "speex_bits.h"
#else
-# include <speex/speex_types.h>
+# include <speex/speexdsp_types.h>
# include <speex/speex_bits.h>
#endif
diff --git a/include/speex/speex_config_types.h.in b/include/speex/speexdsp_config_types.h.in
index 3fab2ae..3fab2ae 100644
--- a/include/speex/speex_config_types.h.in
+++ b/include/speex/speexdsp_config_types.h.in
diff --git a/include/speex/speex_types.h b/include/speex/speexdsp_types.h
index 59bb5b4..8ab2140 100644
--- a/include/speex/speex_types.h
+++ b/include/speex/speexdsp_types.h
@@ -1,4 +1,4 @@
/* speex_types.h taken from libogg */
/********************************************************************
* *
* THIS FILE IS PART OF THE OggVorbis SOFTWARE CODEC SOURCE CODE. *
@@ -16,7 +16,7 @@
********************************************************************/
/**
- @file speex_types.h
+ @file speexdsp_types.h
@brief Speex types
*/
#ifndef _SPEEX_TYPES_H
@@ -120,9 +120,9 @@
#else
# ifdef _BUILD_SPEEX
-# include "include/speex/speex_config_types.h"
+# include "include/speex/speexdsp_config_types.h"
#else
-# include <speex/speex_config_types.h>
+# include <speex/speexdsp_config_types.h>
#endif
#endif
@@ -1,4 +1,4 @@
-/* speex_types.h taken from libogg */
+/* speexdsp_types.h taken from libogg */
/********************************************************************
* *